@@ -3,6 +3,7 @@
 # @Time : 2020/5/18 13:51
 # @Author : yangpingyan@gmail.com
 from .chrome_api import *
+from .thread_api import *
 
-__VERSION__ = '0.0.13'
-print(f"ypyapi version: {__VERSION__}")
+__VERSION__ = '0.0.14'
+# print(f"ypyapi version: {__VERSION__}")
